module.exports = {

    'exists' : function(check) {
        return check('vigenere.c exists')
        .exists('vigenere.c');
    },

    'compiles' : ['exists', function(check) {
        return check('vigenere.c compiles')
        .run('clang -o vigenere vigenere.c -lcs50 -lm')
        .exit(0);
    }],

    './vigenere a' : ['compiles', function(check) {
        return check('encrypts "a" as "a" using "a" as keyword')
        .run('clang -o vigenere vigenere.c -lcs50 -lm')
        .exit(0)
        .run('./vigenere a')
        .stdin('a\n')
        .stdout(/a\n/)
        .exit(0);
    }],

    './vigenere baz' : ['compiles', function(check) {
        return check('encrypts "barfoo" as "caqgon" using "baz" as keyword')
        .run('clang -o vigenere vigenere.c -lcs50 -lm')
        .exit(0)
        .run('./vigenere baz')
        .stdin('barfoo\n')
        .stdout(/caqgon\n/)
        .exit(0);
    }],

    './vigenere BaZ' : ['compiles', function(check) {
        return check('encrypts "BaRFoo" as "CaQGon" using "BaZ" as keyword')
        .run('clang -o vigenere vigenere.c -lcs50 -lm')
        .exit(0)
        .run('./vigenere BaZ')
        .stdin('BaRFoo\n')
        .stdout(/CaQGon\n/)
        .exit(0);
    }],

    './vigenere BAZ' : ['compiles', function(check) {
        return check('encrypts "BARFOO" as "CAQGON" using "BAZ" as keyword')
        .run('clang -o vigenere vigenere.c -lcs50 -lm')
        .exit(0)
        .run('./vigenere BAZ')
        .stdin('BARFOO\n')
        .stdout(/CAQGON\n/)
        .exit(0);
    }],

    './vigenere baz' : ['compiles', function(check) {
        return check('encrypts "world!$?" as "xoqmd!$?" using "baz" as keyword')
        .run('clang -o vigenere vigenere.c -lcs50 -lm')
        .exit(0)
        .run('./vigenere baz')
        .stdin('world!$?\n')
        .stdout(/xoqmd!\$\?\n/)
        .exit(0);
    }],

    './vigenere baz' : ['compiles', function(check) {
        return check('encrypts "world, say hello!" as "xoqmd, rby gflkp!" using "baz" as keyword')
        .run('clang -o vigenere vigenere.c -lcs50 -lm')
        .exit(0)
        .run('./vigenere baz')
        .stdin('world, say hello!\n')
        .stdout(/xoqmd, rby gflkp!\n/)
        .exit(0);
    }],

    './vignere' : ['compiles', function(check) {
        return check('handles lack of argv[1]')
        .run('clang -o vigenere vigenere.c -lcs50 -lm')
        .exit(0)
        .run('./vigenere')
        .stdout(/[\s\S]*/)
        .exit(1);
    }],

    './vigenere 1 2 3' : ['compiles', function(check) {
        return check('handles argc > 2')
        .run('clang -o vigenere vigenere.c -lcs50 -lm')
        .exit(0)
        .run('./vigenere 1 2 3')
        .stdout(/[\s\S]*/)
        .exit(1);
    }],

    './vigenere Hax0r2' : ['compiles', function(check) {
        return check('rejects "Hax0r2" as keyword')
        .run('clang -o vigenere vigenere.c -lcs50 -lm')
        .exit(0)
        .run('./vigenere "Hax0r2"')
        .stdout(/[\s\S]*/)
        .exit(1);
    }]

};
